'==============================================================================
'Filename   Si570_LO_2.00_Config.bas
'Version    2.00
'Date       2011-03-11
'Purpose    Configuration of Local oscillator for TRX with band control using Si570
'           to be included ($Include) in main code
'Author     Georg Latzel, DL6GL
'Copyright  (c) Georg Latzel, free for private use
'Compiler   BASCOM-AVR 1.11.9.8
'           For readable "camel case" variables mark "Don't change case"
'           in Options-Programmer-Environment-Editor
'Edit history
'V2.00      2010-03-11, first release
'==============================================================================

'Settings and band data are stored in EEPROM
'For a new chip EEPROM is initialized with data:
'lngStep       1.0 kHz        Freq. tuning step
'lngIFSSB      9 MHz          SSB IF filter center freq
'wrdLSBOff     1.5 kHz        LSB offset relative to lngIF
'bytLSBSign    1              Subtract offset
'wrdUSBOff     1.5 kHz        LSB offset relative to lngIF
'bytUSBSign    2              add offset
'lngIFCW       9 MHz          CW IF filter center freq
'wrdCWOff      0.8 kHz        CW offset relative to lngIF
'bytCWSign     2              add offset
'lngIFFM       9 MHz          FM IF filter center freq
'bytLODiv      1              mixer divider factor
'bytAddrSi570  hex55          Si570 factory setting slave address
'dblFxtal      114.320760 MHz internal xtal freq. for used Si570
'bytI2C_BPF1   B01110000      Write Addr. PCF8574A bandpass filter bank 1
'bytI2C_BPF2   B01110010      Write Addr. PCF8574A bandpass filter bank 2
'Band data     160-80-60-40-30-20-17-15-12-10-6-2 meters, max 12 bands
'bytBandUsed   band is used: 1, not used: 0
'bytBand       wave length (m)
'bytBandBPF    number of bandpass filter (1, 2,...) used for this band
'              2 adjacent bands may share 1 BPF, e.g. 12+10m (same BPF No.)
'              Attention! must be consecutive numbers (1, 2, 3, ...)
'              for the used bands
'              e.g. if 60 m is not used (bytBandUsed = 0), but 160, 80 & 40m,
'              set bytBandBPF = 1, 2, 0, 3 for 160, 80, 60, 40m
'              If the upper bands 6 & 2m are not used the bytBandBPF number
'              is unimportant, because these bands are not read from EEPROM
'              The BPF banks (PCF8574A # 1 and # 2) are selected by bytBandBPF
'              for the used bands (bytBandUsed = 1).
'              if the max. number is <= 8 only bank 1 is used (1 PCF8574A)
'              if the max. number is > 8 both banks are used (2 PCF8574A)
'lngBandLo     Lower band frequency limit (Hz)
'lngBandHi     Upper band frequency limit (Hz)
$Nocompile

   'IF center freq and LSB/USB/CW offsets
   lngStep = 1000                                 'Tuning step (Hz)
   lngIFSSB = 9006700                             'SSB IF center freq.(Hz)
   lngIFCW = 9006800                              'CW IF center freq.(Hz)
   lngIFFM = 9006900                              'FM IF center freq.(Hz)
   wrdLSBOff = 1500                               'LSB offset to SSB IF center (Hz)
   wrdUSBOff = 1500                               'USB offset to SSB IF center (Hz)
   wrdCWOff = 800                                 'CW offset to CW IF center (Hz)
   bytLSBSign = 1                                 'Sign of LSB offset (-)
   bytUSBSign = 2                                 'Sign of LSB offset (+)
   bytCWSign = 2                                  'Sign of CW offset (+)

   'Si570 data
   bytLODiv = 1                                   'Mixer divider factor
   bytAddrSi570 = &h55                            'Si570 slave address (hex55)
   lngFxtal = 114320760                           'used Si570 internal xtal freq (Hz)


   'BPF switching data
   bytI2C_BPF1 = &B01110000                       'I2C addr. 1st PCF8574A (BPF1 H70)
   bytI2C_BPF2 = &B01110010                       'I2C addr. 2nd PCF8574A (BPF2 H72)
   'bytI2C_BPF2 = &B01110100                       'I2C addr. 2nd PCF8574A (BPF2 H74)

   'lower & upper band limits (Hz) for EEPROM
   bytBandUsed(1) = 1                             '1=used, 0=not used
   bytBand(1) = 160                               '160m
   bytBandBPF(1) = 1                              '160m on BPF No. 1
   lngBandLo(1) = 1810000
   lngBandHi(1) = 2000000

   bytBandUsed(2) = 1                             '1=used, 0=not used
   bytBand(2) = 80                                '80m
   bytBandBPF(2) = 2                              '80m on BPF No. 2
   lngBandLo(2) = 3500000
   lngBandHi(2) = 3800000

   bytBandUsed(3) = 1                             '1=used, 0=not used
   bytBand(3) = 60                                '60m
   bytBandBPF(3) = 3                              '60m on BPF No. 3
   lngBandLo(3) = 5250000
   lngBandHi(3) = 5450000

   bytBandUsed(4) = 1                             '1=used, 0=not used
   bytBand(4) = 40                                '40m
   bytBandBPF(4) = 4                              '40m on BPF No. 4
   lngBandLo(4) = 7000000
   lngBandHi(4) = 7200000

   bytBandUsed(5) = 1                             '1=used, 0=not used
   bytBand(5) = 30                                '30m
   bytBandBPF(5) = 5                              '30m on BPF No. 5
   lngBandLo(5) = 10100000
   lngBandHi(5) = 10150000

   bytBandUsed(6) = 1                             '1=used, 0=not used
   bytBand(6) = 20                                '20m
   bytBandBPF(6) = 6                              '20m on BPF No. 6
   lngBandLo(6) = 14000000
   lngBandHi(6) = 14350000

   bytBandUsed(7) = 1                             '1=used, 0=not used
   bytBand(7) = 17                                '17m
   bytBandBPF(7) = 7                              '17m on BPF No. 7
   lngBandLo(7) = 18068000
   lngBandHi(7) = 18168000

   bytBandUsed(8) = 1                             '1=used, 0=not used
   bytBand(8) = 15                                '15m
   bytBandBPF(8) = 7                              '15m on BPF No. 7
   lngBandLo(8) = 21000000
   lngBandHi(8) = 21450000

   bytBandUsed(9) = 1                             '1=used, 0=not used
   bytBand(9) = 12                                '12m
   bytBandBPF(9) = 8                              '12m on BPF No. 8
   lngBandLo(9) = 24890000
   lngBandHi(9) = 24990000

   bytBandUsed(10) = 1                            '1=used, 0=not used
   bytBand(10) = 10                               '10m
   bytBandBPF(10) = 8                             '10m on BPF No. 8
   lngBandLo(10) = 28000000
   lngBandHi(10) = 29700000

   bytBandUsed(11) = 1                            '1=used, 0=not used
   bytBand(11) = 6                                '6m
   bytBandBPF(11) = 9                             '6m on BPF No. 9
   lngBandLo(11) = 50080000
   lngBandHi(11) = 51000000

   bytBandUsed(12) = 0                            '1=used, 0=not used
   bytBand(12) = 2                                '2m
   bytBandBPF(12) = 10                            '2m on BPF No. 10
   lngBandLo(12) = 144000000
   lngBandHi(12) = 146000000